@@ -1,6 +1,6 @@
 /*
 
-$Id: gdisp_sampling.c,v 1.21 2006/11/08 21:31:12 esteban Exp $
+$Id: gdisp_sampling.c,v 1.24 2007/11/14 21:53:20 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -941,11 +941,10 @@ gdisp_samplingThread (void *data )
   /*
    * Tell TSP core to stop sampling process.
    */
-  if (requestStatus == FALSE) {
-    requestStatus = 0;
-  }
-  else {
+  if (requestStatus == TSP_STATUS_OK) {
+
     requestStatus = TSP_consumer_request_sample_destroy(provider->pHandle);
+
   }
 
   if (TSP_STATUS_OK != requestStatus) {
@@ -1064,6 +1063,20 @@ gdisp_preSamplingThread (void *data )
   fflush (stdout);
 #endif
 
+  /*
+   * ========================== WARNING ======================
+   * From esteban.
+   * I disagree with the calling of the procedure here.
+   * It is meant for being called when the sampling process is over, whereas
+   * it is not the case at the end of this thread.
+   * As this procedure does nothing by now, it is not a hurry to find the correct
+   * place (should be at the end of the 'stopSamplingProcess' procedure according to me).
+   */
+  gdisp_freeSymbolsForSampling(kernel);
+  /*
+   * esteban.
+   */
+
   pthread_exit((void*)TRUE);
 
 }
