@@ -1,6 +1,6 @@
 /*
 
-$Id: tsp_common.c,v 1.8 2006/10/18 09:58:48 erk Exp $
+$Id: tsp_common.c,v 1.11 2008/02/05 18:54:09 rhdv Exp $
 
 -----------------------------------------------------------------------
 
@@ -39,13 +39,12 @@ Purpose   : Main implementation for the producer module
 #include <tsp_sys_headers.h>
 #include <tsp_abs_types.h>
 #include <tsp_datastruct.h>
-#include <tsp_simple_trace.h>
 #include <tsp_const_def.h>
 #define TSP_COMMON_C
 #include <tsp_common.h>
 
-#ifdef WIN32
+#ifdef _WIN32
     #define assert(exp)     ((void)0)
 #else
     #include <assert.h>
-#endif
\ No newline at end of file
+#endif
