@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/common/tsp_decoder.c,v 1.5 2006/10/21 08:48:00 erk Exp $
+$Header: /sources/tsp/tsp/src/core/common/tsp_decoder.c,v 1.14 2008/11/22 19:58:10 deweerdt Exp $
 
 -----------------------------------------------------------------------
 
@@ -40,11 +40,15 @@ Purpose   :  Implementation for the functions used to decode the data received
 #include <rpc/xdr.h>
  
 #include <tsp_const_def.h>
+#include <tsp_abs_types.h>
 #include <tsp_datastruct.h>
-#include <tsp_simple_trace.h>
 #include <tsp_decoder.h>
 
-#ifdef WIN32
+#if defined(sun) || defined(__sun) || defined(__rtems__)
+#include <alloca.h>
+#endif
+
+#ifdef _WIN32
     #define assert(exp)     ((void)0)
     #include <malloc.h>
 #else
@@ -65,7 +69,7 @@ int32_t TSP_data_channel_double_decoder(void* out_double, uint32_t dimension,  c
   {
     if( xdr_double(&xhandle, (double*)out_double+i) != TRUE)
     {
-      STRACE_ERROR(("Function xdr_double failed"));
+      STRACE_ERROR("Function xdr_double failed");
       return FALSE;
     }
     else
@@ -79,7 +83,7 @@ int32_t TSP_data_channel_double_decoder(void* out_double, uint32_t dimension,  c
   for(i=0;i<dimension;++i)
   {
     ((uint64_t*)out_double)[i] = TSP_DECODE_DOUBLE_TO_UINT64(in_buf+(i*TSP_SIZEOF_ENCODED_DOUBLE));   
-    STRACE_DEBUG(("decoded DOUBLE = %f, (received) encoded DOUBLE=0x%08llx",((double*)out_double)[i],((uint64_t*)in_buf)[i]));
+    STRACE_DEBUG_MORE("decoded DOUBLE = %f, (received) encoded DOUBLE=0x%"TSP_UINT64_FORMAT,((double*)out_double)[i],((uint64_t*)in_buf)[i]);
   }
 #endif
 
@@ -101,7 +105,7 @@ int32_t TSP_data_channel_float_decoder(void* out_float, uint32_t dimension,  cha
   {
     if( xdr_float(&xhandle, (float*)out_float+i) != TRUE)
     {
-      STRACE_ERROR(("Function xdr_float failed"));
+      STRACE_ERROR("Function xdr_float failed");
       return FALSE;
     }
     else
@@ -178,7 +182,7 @@ int32_t TSP_data_channel_int32_decoder(void* out_int32, uint32_t dimension,  cha
   {
     if( xdr_int(&xhandle, (int32_t*)out_int32+i) != TRUE)
     {
-      STRACE_ERROR(("Function xdr_float failed"));
+      STRACE_ERROR("Function xdr_float failed");
       return FALSE;
     }
     else
@@ -204,7 +208,7 @@ int32_t TSP_data_channel_int64_decoder(void* out_int64, uint32_t dimension,  cha
   uint32_t i;
 
 
-#ifndef TSP_NO_XDR_ENCODE
+#if !defined(TSP_NO_XDR_ENCODE ) && !defined(_WIN32)
 
   XDR xhandle;
   xdrmem_create(&xhandle, in_buf, TSP_SIZEOF_ENCODED_INT64, XDR_DECODE);
@@ -213,7 +217,7 @@ int32_t TSP_data_channel_int64_decoder(void* out_int64, uint32_t dimension,  cha
   {
     if( xdr_hyper(&xhandle, (int64_t*)out_int64+i) != TRUE)
     {
-      STRACE_ERROR(("Function xdr_float failed"));
+      STRACE_ERROR("Function xdr_float failed");
       return FALSE;
     }
     else
@@ -288,7 +292,7 @@ int32_t TSP_data_channel_uint32_decoder(void* out_uint32, uint32_t dimension,  c
   {
     if( xdr_int(&xhandle, (uint32_t*)out_uint32+i) != TRUE)
     {
-      STRACE_ERROR(("Function xdr_float failed"));
+      STRACE_ERROR("Function xdr_float failed");
       return FALSE;
     }
     else
@@ -314,7 +318,7 @@ int32_t TSP_data_channel_uint64_decoder(void* out_uint64, uint32_t dimension,  c
   uint32_t i;
 
 
-#ifndef TSP_NO_XDR_ENCODE
+#if !defined(TSP_NO_XDR_ENCODE ) && !defined(_WIN32)
 
   XDR xhandle;
   xdrmem_create(&xhandle, in_buf, TSP_SIZEOF_ENCODED_UINT64, XDR_DECODE);
@@ -323,7 +327,7 @@ int32_t TSP_data_channel_uint64_decoder(void* out_uint64, uint32_t dimension,  c
   {
     if( xdr_hyper(&xhandle, (uint64_t*)out_uint64+i) != TRUE)
     {
-      STRACE_ERROR(("Function xdr_float failed"));
+      STRACE_ERROR("Function xdr_float failed");
       return FALSE;
     }
     else
@@ -504,9 +508,8 @@ TSP_data_channel_get_encoded_size(TSP_datatype_t type) {
     return TSP_SIZEOF_ENCODED_USER;
         
   default:
-    STRACE_ERROR(("Unknown TSP Type <%d>",type))
+    STRACE_ERROR("Unknown TSP Type <%d>",type);
     return 0;
-
   }
 }
 
