@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/ctrl/tsp_data_sender.c,v 1.26 2006/10/18 09:58:48 erk Exp $
+$Header: /sources/tsp/tsp/src/core/ctrl/tsp_data_sender.c,v 1.31 2008/02/05 18:54:09 rhdv Exp $
 
 -----------------------------------------------------------------------
 
@@ -36,13 +36,14 @@ stream  for the asked symbols
 -----------------------------------------------------------------------
  */
 
-#ifdef WIN32
+#ifdef _WIN32
     #define assert(exp)     ((void)0)
 #else
     #include <assert.h>
 #endif
 
 #include <tsp_sys_headers.h>
+#include <tsp_abs_types.h>
 #include <rpc/types.h>
 #include <rpc/xdr.h>
 #include <tsp_data_sender.h>
@@ -79,17 +80,18 @@ typedef struct TSP_struct_data_sender_t TSP_struct_data_sender_t;
 
 
 TSP_data_sender_t 
-TSP_data_sender_create(int fifo_size, int max_group_size) {
+TSP_data_sender_create(int fifo_size, uint32_t group_max_byte_size) {
   
   TSP_struct_data_sender_t* sender;
   
   sender = (TSP_struct_data_sender_t*)calloc(1, sizeof(TSP_struct_data_sender_t));
-  TSP_CHECK_ALLOC(sender, 0);
+  TSP_CHECK_ALLOC(sender, NULL);
 
   /* init */
-  sender->fifo_full = FALSE;
-  sender->buffer_size = TSP_DATA_STREAM_MAX_BUFFER_SIZE(max_group_size);
+  sender->fifo_full   = FALSE;
+  sender->buffer_size = TSP_DATA_STREAM_MAX_BUFFER_SIZE(group_max_byte_size);
 
+  STRACE_DEBUG("Data Sender buffer size is: <%d> byte(s)",sender->buffer_size);
   /* Create the sender stream with its fifo size*/
   sender->stream_sender = (TSP_data_sender_t)TSP_stream_sender_create(fifo_size, sender->buffer_size);
   if (sender->stream_sender) {      
@@ -98,7 +100,7 @@ TSP_data_sender_create(int fifo_size, int max_group_size) {
     if (sender->use_fifo) {
       sender->out_item = 0;
       sender->out_fifo = TSP_stream_sender_get_ringbuf(sender->stream_sender);
-      assert( sender->out_fifo);
+      assert(sender->out_fifo);
     }
     else {
       sender->out_fifo = 0;
@@ -107,9 +109,9 @@ TSP_data_sender_create(int fifo_size, int max_group_size) {
     }
   }
   else {
-    STRACE_ERROR(("Function TSP_stream_sender_create failed"));
+    STRACE_ERROR("Function TSP_stream_sender_create failed");
     free(sender);
-    sender = 0;
+    sender = NULL;
   }
   return sender;
 } /* end of TSP_data_sender_create */
@@ -199,7 +201,7 @@ TSP_data_sender_to_stream_sender(TSP_struct_data_sender_t* data_sender,
       if(!TSP_stream_sender_send(data_sender->stream_sender,
 				 TSP_STREAM_SENDER_ITEM_BUF(tosend),
 				 tosend->len) ) {
-	  STRACE_WARNING(("Function TSP_stream_sender_send failed "));
+	  STRACE_WARNING("Function TSP_stream_sender_send failed ");
 	  ret = FALSE;
 	}  
     }
@@ -240,7 +242,7 @@ int TSP_data_sender_send_msg_ctrl(TSP_data_sender_t sender, TSP_msg_ctrl_t msg_c
       tsp_reserved_group = TSP_RESERVED_GROUP_CONSUMER_DATA_LOST;
       break;
     default:
-      STRACE_ERROR(("We should not be there..."));
+      STRACE_ERROR("We should not be there...");
       assert(0);
       return FALSE;
     }
@@ -289,13 +291,23 @@ TSP_data_sender_send(TSP_data_sender_t _sender, TSP_groups_t _groups, time_stamp
   int size;
   TSP_stream_sender_item_t* tosend;
 
+  /* 
+   * Time stamp is the TSP time stamp 
+   * cycle counter
+   * so that the TSP group index 
+   * whose data is to be sent at this "times_tamp"  
+   * only depends on the current time stamp.
+   */
   group_index = time_stamp % groups_table->table_len;
-  group = &(groups_table->groups[group_index]);
+  group       = &(groups_table->groups[group_index]);
 
   /* get out buffer if it is available */
   tosend = TSP_data_sender_get_out_item(data_sender);
     
-  /* If it is not available, try net time */
+  /* 
+   * If it is not available, try next time 
+   * FIXME erk: why? could we just skip a cycle?
+   */
 
   /* FIXME : uses packet format as described in the protocol spec */
   if (tosend) {
@@ -311,8 +323,8 @@ TSP_data_sender_send(TSP_data_sender_t _sender, TSP_groups_t _groups, time_stamp
 	   * FIXME : we cannot STRACE_DEBUG value simply due
 	   * to multi-type handling 
 	   */
-	  /* STRACE_DEBUG(("Gr=%d V=%f", group_index, *(double*)(group->items[i].data))); */
-	  STRACE_DEBUG(("Gr=%d Ne=%d", group_index, group->items[i].nelem));
+	  /* STRACE_DEBUG("Gr=%d V=%f", group_index, *(double*)(group->items[i].data)); */
+	  STRACE_DEBUG_MORE("Gr=%d Ne=%d", group_index, group->items[i].nelem);
 	  
 	  /* Call encode function */
 	  assert(group->items[i].data_encoder);
@@ -321,7 +333,7 @@ TSP_data_sender_send(TSP_data_sender_t _sender, TSP_groups_t _groups, time_stamp
 						buf_char,
 						data_sender->buffer_size - ( buf_char - buf_main) );
 	  if ( 0 == size ) {
-	    STRACE_ERROR(("data_encoder failed"));	    
+	    STRACE_ERROR("data_encoder failed");
 	    ret = FALSE;
 	    break;
 	  }
