@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/rpc/tsp_server.c,v 1.33 2006/10/21 08:48:00 erk Exp $
+$Header: /sources/tsp/tsp/src/core/rpc/tsp_server.c,v 1.39 2008/11/12 12:32:39 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -179,7 +179,7 @@ int * tsp_request_async_sample_write_1_svc(TSP_async_sample_t async_sample_write
   
 
   /* endianity managment*/
-/*   STRACE_DEBUG(("Len=%d,  pgi = %d value = %f et ret = %d", async_sample_write.data.data_len, async_sample_write.provider_global_index,(double*)(async_sample_write.data.data_val),ret)); */
+/*   STRACE_DEBUG("Len=%d,  pgi = %d value = %f et ret = %d", async_sample_write.data.data_len, async_sample_write.provider_global_index,(double*)(async_sample_write.data.data_val),ret); */
 
 /*   switch (async_sample_write.data.data_len) { */
 /*   case 2:  */
@@ -196,11 +196,11 @@ int * tsp_request_async_sample_write_1_svc(TSP_async_sample_t async_sample_write
 /*   } */
 	
 
-  STRACE_DEBUG(("TSP_SERVER Before async_write : pgi %d value %s return %d ",async_sample_write.provider_global_index,async_sample_write.data.data_val,ret ));
+  STRACE_DEBUG("TSP_SERVER Before async_write : pgi %d value %s return %d ",async_sample_write.provider_global_index,async_sample_write.data.data_val,ret);
   
   ret = TSP_provider_request_async_sample_write(&async_sample_write);	
   
-  STRACE_DEBUG(("TSP_SERVER After async_write : pgi %d value %s return %d ",async_sample_write.provider_global_index,async_sample_write.data.data_val,ret ));
+  STRACE_DEBUG("TSP_SERVER After async_write : pgi %d value %s return %d ",async_sample_write.provider_global_index,async_sample_write.data.data_val,ret);
 
   return &ret;
   
@@ -211,7 +211,7 @@ TSP_async_sample_t * tsp_request_async_sample_read_1_svc(TSP_async_sample_t asyn
   static TSP_async_sample_t ret;
   
   /* endianity managment*/
-/*   STRACE_DEBUG(("Len=%d,  pgi = %d value = %f et ret = %d", async_sample_read.data.data_len, async_sample_read.provider_global_index,(double*)(async_sample_read.data.data_val),ret)); */
+/*   STRACE_DEBUG("Len=%d,  pgi = %d value = %f et ret = %d", async_sample_read.data.data_len, async_sample_read.provider_global_index,(double*)(async_sample_read.data.data_val),ret); */
 
 /*   switch (async_sample_read.data.data_len) { */
 /*   case 2:  */
@@ -258,6 +258,7 @@ static int TSP_rpc_init(TSP_rpc_request_config_t *config)
   return config->server_number;
 }
 
+#if !defined(__rtems__)
 static void TSP_rpc_run(TSP_rpc_request_config_t *config)
 {
   int32_t rpc_progid = TSP_get_progid(config->server_number);
@@ -268,27 +269,76 @@ static void TSP_rpc_run(TSP_rpc_request_config_t *config)
   config->xprt = svctcp_create(RPC_ANYSOCK, 0, 0);
   if (config->xprt == NULL) 
     {
-      STRACE_ERROR(("Cannot create TCP service"));
+      STRACE_ERROR("Cannot create TCP service");
       return;
     }
 
   if (!svc_register(config->xprt, rpc_progid, TSP_RPC_VERSION_INITIAL, tsp_rpc_1, IPPROTO_TCP))
     {
-      STRACE_ERROR(("RPC server unable to register ProgId=%X",  rpc_progid));
+      STRACE_ERROR("RPC server unable to register ProgId=%X",  rpc_progid);
       return;
     }
 
-  STRACE_DEBUG(("RPC server is being be started with ProgId=%X", rpc_progid));
+  STRACE_DEBUG("RPC server is being be started with ProgId=%X", rpc_progid);
   
-  STRACE_DEBUG(("launching svc_run..."));
+  STRACE_DEBUG("launching svc_run...");
   svc_run();
-  STRACE_INFO(("svc_run returned"));
+  STRACE_INFO("svc_run returned");
 
 }
+#else
+static void TSP_rpc_run(TSP_rpc_request_config_t *config)
+{
+	int32_t rpc_progid = TSP_get_progid(config->server_number);
+	int sock;
+	struct sockaddr_in srv_addr;
+	SVCXPRT *transp;
+	bool_t status;
+
+	/*
+	 * Create socket
+	 */
+	sock = socket (AF_INET, SOCK_STREAM, IPPROTO_TCP);
+	if (sock < 0) {
+		perror ("socket creation problem");
+		return 1;
+	}
+
+	/*
+	 * Bind to local address
+	 */
+	srv_addr.sin_family = htons (AF_INET);
+	srv_addr.sin_port = htons (TCP_PORT);
+	srv_addr.sin_addr.s_addr = htonl (INADDR_ANY);
+	if (bind (sock, (struct sockaddr *)&srv_addr, sizeof srv_addr) < 0) {
+		STRACE_ERROR("RPC server unable to register ProgId=%X",  strerror(errno));
+		return 2;
+	}
+
+	/*
+	 * Create TCP server
+	 */
+	config->xprt = svctcp_create(sock, 0, 0);
+	if (config->xprt == NULL) {
+		STRACE_ERROR(("Cannot create TCP service"));
+		return;
+	}
+	if (!svc_register(config->xprt, rpc_progid, TSP_RPC_VERSION_INITIAL, tsp_rpc_1, 0))
+	{
+		STRACE_ERROR("RPC server unable to register ProgId=%X",  rpc_progid);
+		return;
+	}
+	STRACE_DEBUG(("RPC server is being be started with ProgId=%X", rpc_progid));
+
+	STRACE_DEBUG("launching svc_run...");
+	svc_run();
+	STRACE_INFO("svc_run returned");
+}
+#endif /* !defined(__rtems__) */
 
 static void TSP_rpc_stop(TSP_rpc_request_config_t *config)
 {
-  /* STRACE_DEBUG(("calling svc_exit...")); */
+  /* STRACE_DEBUG("calling svc_exit..."); */
   /* svc_destroy(config->xprt); */
 
   /* Clean-up Port map so that next provider could use this ProgId */
@@ -299,27 +349,27 @@ static void TSP_rpc_stop(TSP_rpc_request_config_t *config)
     }
 }
 
-int TSP_rpc_request(TSP_provider_request_handler_t* this)
+int TSP_rpc_request(TSP_provider_request_handler_t* cthis)
 {
-  this->config             = TSP_rpc_request_config;
-  this->run                = TSP_rpc_request_run;
-  this->stop               = TSP_rpc_request_stop;
-  this->url                = TSP_rpc_request_url;
-#if defined (WIN32)
+  cthis->config             = TSP_rpc_request_config;
+  cthis->run                = TSP_rpc_request_run;
+  cthis->stop               = TSP_rpc_request_stop;
+  cthis->url                = TSP_rpc_request_url;
+#if defined (_WIN32)
   /* structure pthread_t different under Windows */
-  this->tid.p              = -1;
+  cthis->tid.p              = -1;
 #else
-  this->tid                = (pthread_t)-1;
+  cthis->tid                = (pthread_t)-1;
 #endif
-  this->config_param       = calloc(1, sizeof(TSP_rpc_request_config_t));
+  cthis->config_param       = calloc(1, sizeof(TSP_rpc_request_config_t));
 
-  this->status             = TSP_RQH_STATUS_IDLE;
+  cthis->status             = TSP_RQH_STATUS_IDLE;
   return TRUE;
 }
 
-int TSP_rpc_request_config(TSP_provider_request_handler_t* this)
+int TSP_rpc_request_config(TSP_provider_request_handler_t* cthis)
 {
-  TSP_rpc_request_config_t *config = (TSP_rpc_request_config_t *)(this->config_param);
+  TSP_rpc_request_config_t *config = (TSP_rpc_request_config_t *)(cthis->config_param);
   char  hostname[MAXHOSTNAMELEN+1];
   char* servername;
   int  hostnameOk;
@@ -338,8 +388,8 @@ int TSP_rpc_request_config(TSP_provider_request_handler_t* this)
   
   config->server_number = TSP_rpc_init(config);
   if(config->server_number < 0) {
-      STRACE_ERROR(("unable to register any RPC progid :\n\tcheck RPC daemons, or use tsp_rpc_cleanup to clean-up all TSP RPC port mapping"));
-      this->status = TSP_RQH_STATUS_IDLE;
+      STRACE_ERROR("unable to register any RPC progid :\n\tcheck RPC daemons, or use tsp_rpc_cleanup to clean-up all TSP RPC port mapping");
+      cthis->status = TSP_RQH_STATUS_IDLE;
       
       return FALSE;
   }
@@ -348,7 +398,7 @@ int TSP_rpc_request_config(TSP_provider_request_handler_t* this)
 #if NUMERIC_HOST
     myhost = gethostbyname(hostname);
     if (myhost == NULL) {
-      STRACE_ERROR(("Cannot gethostbyname '(hostname --> @IP)' for host <%s> check your /etc/hosts file.\n",hostname));
+      STRACE_ERROR("Cannot gethostbyname '(hostname --> @IP)' for host <%s> check your /etc/hosts file.",hostname);
       /* be tolerant we keep going with hostname but... consumer may not handle this properly */    
     } else {
      /* 
@@ -356,16 +406,19 @@ int TSP_rpc_request_config(TSP_provider_request_handler_t* this)
       * to avoid name -> IP resolution on consumer side 
       */
       memset(hostname,0,sizeof(hostname));
-      myu.addr = (uint32_t)ntohl(*((uint32_t*)myhost->h_addr_list[0]));
-      sprintf(hostname,"%d.%d.%d.%d",myu.parts[3], myu.parts[2], myu.parts[1], myu.parts[0]);
+      myu.addr =*((uint32_t*)myhost->h_addr_list[0]);
+
+      sprintf(hostname,"%d.%d.%d.%d",myu.parts[0], myu.parts[1], myu.parts[2], myu.parts[3]);
+
     }
+
 #endif
     servername = (char*)TSP_provider_get_name();
     
     sprintf(config->url, /* TSP_URL_MAXLENGTH, pour snprintf quand Solaris 2.5 sera mort */
 	    TSP_URL_FORMAT, TSP_RPC_PROTOCOL, hostname, servername, config->server_number);
     
-    this->status = TSP_RQH_STATUS_CONFIGURED;
+    cthis->status = TSP_RQH_STATUS_CONFIGURED;
     
     return TRUE;
   }
@@ -374,38 +427,38 @@ int TSP_rpc_request_config(TSP_provider_request_handler_t* this)
 
 
 
-void* TSP_rpc_request_run(TSP_provider_request_handler_t* this)
+void* TSP_rpc_request_run(void* cthis)
 {
-
-  TSP_rpc_request_config_t *config = (TSP_rpc_request_config_t *)(this->config_param);
+  TSP_provider_request_handler_t* rthis = (TSP_provider_request_handler_t*) cthis;
+  TSP_rpc_request_config_t *config = (TSP_rpc_request_config_t *)(rthis->config_param);
 
   /* pthread_detach(pthread_self()); */ /* FIXME shoudl we do this */ 
 
   if(config->server_number >= 0)
     {
-      this->status = TSP_RQH_STATUS_RUNNING;
+      rthis->status = TSP_RQH_STATUS_RUNNING;
       TSP_rpc_run(config);
-      this->status = TSP_RQH_STATUS_IDLE;
+      rthis->status = TSP_RQH_STATUS_IDLE;
    }
 
   return (void*)NULL;
 } /* end of TSP_rpc_request_run */
 
-char *TSP_rpc_request_url(TSP_provider_request_handler_t* this)
+char *TSP_rpc_request_url(TSP_provider_request_handler_t* cthis)
 {
-  TSP_rpc_request_config_t *config = (TSP_rpc_request_config_t*)(this->config_param);
-  if(this->status == TSP_RQH_STATUS_RUNNING)
+  TSP_rpc_request_config_t *config = (TSP_rpc_request_config_t*)(cthis->config_param);
+  if(cthis->status == TSP_RQH_STATUS_RUNNING)
     return config->url;
   else
     return NULL;
 }
 
-int TSP_rpc_request_stop(TSP_provider_request_handler_t* this)
+int TSP_rpc_request_stop(TSP_provider_request_handler_t* cthis)
 {
-  TSP_rpc_request_config_t *config = (TSP_rpc_request_config_t*)(this->config_param);
+  TSP_rpc_request_config_t *config = (TSP_rpc_request_config_t*)(cthis->config_param);
   
   TSP_rpc_stop(config);
-  this->status = TSP_RQH_STATUS_STOPPED;
+  cthis->status = TSP_RQH_STATUS_STOPPED;
 
   return TRUE;
 } /* end of TSP_rpc_request_stop */
