@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/xmlrpc/tsp_xmlrpc_server.c,v 1.8 2006/10/21 08:48:00 erk Exp $
+$Header: /sources/tsp/tsp/src/core/xmlrpc/tsp_xmlrpc_server.c,v 1.26 2008/02/05 18:54:11 rhdv Exp $
 
 -----------------------------------------------------------------------
 
@@ -53,7 +53,7 @@ Purpose   :
 #include <xmlrpc.h>
 #include <xmlrpc_server_abyss.h>
 
-/*#include "tsp_request_handler.h"*/
+/*#include "tsp_request_handler.h"*/  
 
 
 #include "tsp_xmlrpc_util.h"
@@ -84,7 +84,7 @@ xmlrpc_value *tsp_provider_information_xmlrpc(xmlrpc_env *env, xmlrpc_value *par
   TSP_provider_info_t server_info;
 
   server_info.info = strdup(GLU_get_server_name());
-  STRACE_DEBUG(("server_info.info: %s\n",server_info.info));
+  STRACE_DEBUG("server_info.info: %s",server_info.info);
   return xmlrpc_build_value(env, "{s:s}", "info", server_info.info);
 }
 
@@ -110,7 +110,7 @@ xmlrpc_value * tsp_request_open_xmlrpc(xmlrpc_env *env, xmlrpc_value *param_arra
 }
 
 
-void *tsp_request_close_xmlrpc(xmlrpc_env *env, xmlrpc_value *param_array, void *user_data)
+xmlrpc_value *tsp_request_close_xmlrpc(xmlrpc_env *env, xmlrpc_value *param_array, void *user_data)
 {
 
   xmlrpc_value *xr_result;
@@ -160,7 +160,7 @@ xmlrpc_value * tsp_request_information_xmlrpc (xmlrpc_env *env, xmlrpc_value *pa
   for (i=0; i < ans_sample.symbols.TSP_sample_symbol_info_list_t_len; i++) {
 	xmlrpc_value *symbol;
 
-	symbol = xmlrpc_build_value(env, "{s:s,s:i,s:i,s:i,s:i,s:i,s:i,s:i}",
+	symbol = xmlrpc_build_value(env, "{s:s,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i}",
 								"name", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].name,
 								"provider_global_index", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].provider_global_index,
 								"provider_group_index", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].provider_group_index,
@@ -169,6 +169,9 @@ xmlrpc_value * tsp_request_information_xmlrpc (xmlrpc_env *env, xmlrpc_value *pa
 								"dimension", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].dimension,
 								"period", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].period,
                                 "phase", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].phase,
+                                "nelem", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].nelem,
+                                "offset", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].offset,                                
+                                "dimension", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].dimension,
 								"type", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].type);
                                 
 	xmlrpc_array_append_item(env, value, symbol);
@@ -211,7 +214,7 @@ xmlrpc_value * tsp_request_sample_xmlrpc (xmlrpc_env *env, xmlrpc_value *param_a
 	xmlrpc_value *symbol;
 
 
-	symbol = xmlrpc_build_value(env, "{s:s,s:i,s:i,s:i,s:i,s:i,s:i,s:i}",
+	symbol = xmlrpc_build_value(env, "{s:s,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i}",
 								"name", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].name,
 								"provider_global_index", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].provider_global_index,
 								"provider_group_index", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].provider_group_index,
@@ -220,6 +223,9 @@ xmlrpc_value * tsp_request_sample_xmlrpc (xmlrpc_env *env, xmlrpc_value *param_a
 								"dimension", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].dimension,
 								"period", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].period,
                                 "phase", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].phase,
+                                "nelem", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].nelem,
+                                "offset", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].offset,
+                                "dimension", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].dimension,
 								"type", ans_sample.symbols.TSP_sample_symbol_info_list_t_val[i].type);
 	xmlrpc_array_append_item(env, value, symbol);
   }
@@ -279,22 +285,7 @@ tsp_request_sample_destroy_xmlrpc (xmlrpc_env *env,
 }
 
 /*==================================================================*/
-
-int TSP_xmlrpc_request(TSP_provider_request_handler_t* this)
-{
-  this->config             = TSP_xmlrpc_request_config;
-  this->run                = TSP_xmlrpc_request_run;
-  this->stop               = TSP_xmlrpc_request_stop;
-  this->url                = TSP_xmlrpc_request_url;
-  this->tid                = (pthread_t)-1;
-
-  this->config_param       = calloc(1, sizeof(TSP_xmlrpc_request_config_t));    
-
-  this->status             = TSP_RQH_STATUS_IDLE;
-  return TRUE;
-}
-
-static clean_exit() 
+static void clean_exit(void)
 {
   _exit(0);
 }
@@ -305,7 +296,7 @@ static void TSP_xmlrpc_run(TSP_xmlrpc_request_config_t *config)
   xmlrpc_registry * registry;
   xmlrpc_env env;
 
-  STRACE_DEBUG(("Launched Abyss server"));
+  STRACE_DEBUG("Launched Abyss server");
 
   atexit(clean_exit);
 
@@ -366,12 +357,41 @@ static void TSP_xmlrpc_run(TSP_xmlrpc_request_config_t *config)
   //TODO: make it configurable
   serverparm.log_file_name = "/dev/stderr";
 
-  STRACE_INFO(("Starting abyss server..."));
+  STRACE_INFO("Starting abyss server...");
   xmlrpc_server_abyss(&env, &serverparm, XMLRPC_APSIZE(log_file_name));
-  STRACE_ERROR(("Abyss server returned"));
+  STRACE_ERROR("Abyss server returned");
   return;
 }
 
+void *TSP_xmlrpc_request_run(void *arg)
+{
+  TSP_provider_request_handler_t* this = arg;
+  TSP_xmlrpc_request_config_t *config = (TSP_xmlrpc_request_config_t *)(this->config_param);
+
+  if(config->server_number >= 0) {
+	this->status = TSP_RQH_STATUS_RUNNING;
+	TSP_xmlrpc_run(config);
+	this->status = TSP_RQH_STATUS_IDLE;
+  }
+
+  return 0;
+} /* end of TSP_xmlrpc_request_run */
+
+
+int TSP_xmlrpc_request(TSP_provider_request_handler_t* this)
+{
+  this->config             = TSP_xmlrpc_request_config;
+  this->run                = TSP_xmlrpc_request_run;
+  this->stop               = TSP_xmlrpc_request_stop;
+  this->url                = TSP_xmlrpc_request_url;
+  this->tid                = (pthread_t)-1;
+
+  this->config_param       = calloc(1, sizeof(TSP_xmlrpc_request_config_t));    
+
+  this->status             = TSP_RQH_STATUS_IDLE;
+  return TRUE;
+}
+
 int TSP_xmlrpc_request_config(TSP_provider_request_handler_t* this)
 {
 
@@ -382,20 +402,6 @@ int TSP_xmlrpc_request_config(TSP_provider_request_handler_t* this)
 
 
 
-void* TSP_xmlrpc_request_run(TSP_provider_request_handler_t* this)
-{
-
-  TSP_xmlrpc_request_config_t *config = (TSP_xmlrpc_request_config_t *)(this->config_param);
-
-  if(config->server_number >= 0) {
-	this->status = TSP_RQH_STATUS_RUNNING;
-	TSP_xmlrpc_run(config);
-	this->status = TSP_RQH_STATUS_IDLE;
-  }
-
-  return (void*)NULL;
-} /* end of TSP_xmlrpc_request_run */
-
 char *TSP_xmlrpc_request_url(TSP_provider_request_handler_t* this)
 {
   TSP_xmlrpc_request_config_t *config = (TSP_xmlrpc_request_config_t*)(this->config_param);
@@ -407,8 +413,6 @@ char *TSP_xmlrpc_request_url(TSP_provider_request_handler_t* this)
 
 int TSP_xmlrpc_request_stop(TSP_provider_request_handler_t* this)
 {
-  TSP_xmlrpc_request_config_t *config = (TSP_xmlrpc_request_config_t*)(this->config_param);
-  
   this->status = TSP_RQH_STATUS_STOPPED;
 
   return TRUE;
